@@ -10,3 +10,18 @@ from testit_pytest.utils import message
 from testit_pytest.utils import attachments
 from testit_pytest.utils import LinkType
 from testit_pytest.utils import step
+
+__all__ = [
+    'workItemID',
+    'displayName',
+    'externalID',
+    'title',
+    'description',
+    'labels',
+    'link',
+    'addLink',
+    'message',
+    'attachments',
+    'LinkType',
+    'step'
+]
